@@ -5,7 +5,9 @@ class PosTaggedWord(Word):
 
     __tag: str
 
-    def __init__(self, name: str, tag: str):
+    def __init__(self,
+                 name: str,
+                 tag: str):
         """
         A constructor of PosTaggedWord which takes name and tag as input and sets the corresponding attributes
 
